@@ -56,7 +56,7 @@ static char ripe_server[] = "whois.ripe.net";
 static char ripe_ris_server[] = "riswhois.ripe.net";
 
 #ifdef STANDALONE
-const char *version = "3.72";                    /* set version string for library and client */
+const char *version = "3.73";                    /* set version string for library and client */
 const char *appname = "WhoB";            	    /* set application name */
 static int go_interactive = 0;                  /* We'll wait on STDIN unless args suggest otherwise */
 static int use_cymru = 0;                       /* Don't use Cymru by default */
@@ -2438,6 +2438,10 @@ int main(int ac, char **av)
             default:
                 usage (av[0]);
         }
+
+    /* Catch hostname input without any arguments */
+    if ((ac - optind) > 0) 
+        go_interactive = 1;
                             
     if (go_interactive > 0) {
     /*  Quickly check stdin for input to avoid David having to type   */
@@ -2487,7 +2491,6 @@ int main(int ac, char **av)
             fprintf(stderr,"Sorry, the subject name you supplied was unreasonably long.\n");
             exit(EXIT_FAILURE);
         } else {
-        
             strncpy(hostname,av[optind],strlen(av[optind]));
             optind++;
         }
